@@ -1,16 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2020-2021 -- leonerd@leonerd.org.uk
 
-package Metrics::Any::Adapter::SignalFx;
+package Metrics::Any::Adapter::SignalFx 0.03;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( Metrics::Any::Adapter::Statsd );
 
-our $VERSION = '0.02';
-
 # See also
 #   https://docs.signalfx.com/en/latest/integrations/agent/monitors/collectd-statsd.html
 
